"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    pricing_plan: str,
    tracker_name: str,
    description: str = None,
    kms_key_id: str = None,
    pricing_plan_data_source: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a tracker resource in your AWS account, which lets you retrieve current and historical location of devices.

    Args:
        description(str, optional): An optional description for the tracker resource. Defaults to None.
        kms_key_id(str, optional): A key identifier for an AWS KMS customer managed key. Enter a key ID, key ARN, alias name, or alias ARN. Defaults to None.
        pricing_plan(str): Specifies the pricing plan for the tracker resource. For additional details and restrictions on each pricing plan option, see the Amazon Location Service pricing page.
        pricing_plan_data_source(str, optional): Specifies the data provider for the tracker resource.   Required value for the following pricing plans: MobileAssetTracking | MobileAssetManagement    For more information about Data Providers, and Pricing plans, see the Amazon Location Service product page.  Amazon Location Service only uses PricingPlanDataSource to calculate billing for your tracker resource. Your data will not be shared with the data provider, and will remain in your AWS account or Region unless you move it.  Valid Values: Esri | Here . Defaults to None.
        tags(Dict, optional): Applies one or more tags to the tracker resource. A tag is a key-value pair helps manage, identify, search, and filter your resources by labelling them. Format: "key" : "value"  Restrictions:   Maximum 50 tags per resource   Each resource tag must be unique with a maximum of one value.   Maximum key length: 128 Unicode characters in UTF-8   Maximum value length: 256 Unicode characters in UTF-8   Can use alphanumeric characters (A–Z, a–z, 0–9), and the following characters: + - = . _ : / @.   . Defaults to None.
        tracker_name(str): The name for the tracker resource. Requirements:   Contain only alphanumeric characters (A-Z, a-z, 0-9) , hyphens (-), periods (.), and underscores (_).   Must be a unique tracker resource name.   No spaces allowed. For example, ExampleTracker.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.init.create(
                ctx, pricing_plan=value, tracker_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.init.create pricing_plan=value, tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="create_tracker",
        op_kwargs={
            "Description": description,
            "KmsKeyId": kms_key_id,
            "PricingPlan": pricing_plan,
            "PricingPlanDataSource": pricing_plan_data_source,
            "Tags": tags,
            "TrackerName": tracker_name,
        },
    )


async def delete(hub, ctx, tracker_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a tracker resource from your AWS account.  This operation deletes the resource permanently. If the tracker resource is in use, you may encounter an error. Make sure that the target resource isn't a dependency for your applications.

    Args:
        tracker_name(str): The name of the tracker resource to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.init.delete(ctx, tracker_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.init.delete tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="delete_tracker",
        op_kwargs={"TrackerName": tracker_name},
    )


async def describe(hub, ctx, tracker_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the tracker resource details.

    Args:
        tracker_name(str): The name of the tracker resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.init.describe(ctx, tracker_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.init.describe tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="describe_tracker",
        op_kwargs={"TrackerName": tracker_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists tracker resources in your AWS account.

    Args:
        max_results(int, optional): An optional limit for the number of resources returned in a single call.  Default value: 100 . Defaults to None.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page.  Default value: null . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="list_trackers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    tracker_name: str,
    description: str = None,
    pricing_plan: str = None,
    pricing_plan_data_source: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified properties of a given tracker resource.

    Args:
        description(str, optional): Updates the description for the tracker resource. Defaults to None.
        pricing_plan(str, optional): Updates the pricing plan for the tracker resource. For more information about each pricing plan option restrictions, see Amazon Location Service pricing. Defaults to None.
        pricing_plan_data_source(str, optional): Updates the data provider for the tracker resource.  A required value for the following pricing plans: MobileAssetTracking| MobileAssetManagement  For more information about data providers and pricing plans, see the Amazon Location Service product page  This can only be updated when updating the PricingPlan in the same request. Amazon Location Service uses PricingPlanDataSource to calculate billing for your tracker resource. Your data won't be shared with the data provider, and will remain in your AWS account and Region unless you move it. . Defaults to None.
        tracker_name(str): The name of the tracker resource to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.tracker.init.update(ctx, tracker_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.tracker.init.update tracker_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="update_tracker",
        op_kwargs={
            "Description": description,
            "PricingPlan": pricing_plan,
            "PricingPlanDataSource": pricing_plan_data_source,
            "TrackerName": tracker_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a JSON-formatted list of information about the specified trail. Fields include information on delivery errors, Amazon SNS and Amazon S3 errors, and start and stop logging times for each trail. This operation returns trail status from a single region. To return trail status from all regions, you must call the operation on each region.

    Args:
        name(str): Specifies the name or the CloudTrail ARN of the trail for which you are requesting status. To get the status of a shadow trail (a replication of the trail in another region), you must specify its ARN. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.trail.status.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.trail.status.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="get_trail_status",
        op_kwargs={"Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a channel's IAM policy.

    Args:
        channel_name(str): The identifier for the channel you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.policy.delete(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.policy.delete channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="delete_channel_policy",
        op_kwargs={"ChannelName": channel_name},
    )


async def get(hub, ctx, channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a channel's IAM policy.

    Args:
        channel_name(str): The identifier for the channel you are working on.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.policy.get(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.policy.get channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="get_channel_policy",
        op_kwargs={"ChannelName": channel_name},
    )


async def put(hub, ctx, channel_name: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an IAM policy for the channel.

    Args:
        channel_name(str): The identifier for the channel you are working on.
        policy(str): Adds an IAM role that determines the permissions of your channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.channel.policy.put(
                ctx, channel_name=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.channel.policy.put channel_name=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="put_channel_policy",
        op_kwargs={"ChannelName": channel_name, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an object lifecycle policy from a container. It takes up to 20 minutes for the change to take effect.

    Args:
        container_name(str): The name of the container that holds the object lifecycle policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.lifecycle_policy.delete(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.lifecycle_policy.delete container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="delete_lifecycle_policy",
        op_kwargs={"ContainerName": container_name},
    )


async def get(hub, ctx, container_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the object lifecycle policy that is assigned to a container.

    Args:
        container_name(str): The name of the container that the object lifecycle policy is assigned to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.lifecycle_policy.get(ctx, container_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.lifecycle_policy.get container_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="get_lifecycle_policy",
        op_kwargs={"ContainerName": container_name},
    )


async def put(hub, ctx, container_name: str, lifecycle_policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Writes an object lifecycle policy to a container. If the container already has an object lifecycle policy, the service replaces the existing policy with the new policy. It takes up to 20 minutes for the change to take effect. For information about how to construct an object lifecycle policy, see Components of an Object Lifecycle Policy.

    Args:
        container_name(str): The name of the container that you want to assign the object lifecycle policy to.
        lifecycle_policy(str): The object lifecycle policy to apply to the container.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore.lifecycle_policy.put(
                ctx, container_name=value, lifecycle_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore.lifecycle_policy.put container_name=value, lifecycle_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore",
        operation="put_lifecycle_policy",
        op_kwargs={
            "ContainerName": container_name,
            "LifecyclePolicy": lifecycle_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, web_acl_id: str, s3_bucket_name: str, ignore_unsupported_type: bool
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS CloudFormation WAFV2 template for the specified web ACL in the specified Amazon S3 bucket. Then, in CloudFormation, you create a stack from the template, to create the web ACL and its resources in AWS WAFV2. Use this to migrate your AWS WAF Classic web ACL to the latest version of AWS WAF. This is part of a larger migration procedure for web ACLs from AWS WAF Classic to the latest version of AWS WAF. For the full procedure, including caveats and manual steps to complete the migration and switch over to the new web ACL, see Migrating your AWS WAF Classic resources to AWS WAF in the AWS WAF Developer Guide.

    Args:
        web_acl_id(str): The UUID of the WAF Classic web ACL that you want to migrate to WAF v2.
        s3_bucket_name(str): The name of the Amazon S3 bucket to store the CloudFormation template in. The S3 bucket must be configured as follows for the migration:    The bucket name must start with aws-waf-migration-. For example, aws-waf-migration-my-web-acl.   The bucket must be in the Region where you are deploying the template. For example, for a web ACL in us-west-2, you must use an Amazon S3 bucket in us-west-2 and you must deploy the template stack to us-west-2.    The bucket policies must permit the migration process to write data. For listings of the bucket policies, see the Examples section.   .
        ignore_unsupported_type(bool): Indicates whether to exclude entities that can't be migrated or to stop the migration. Set this to true to ignore unsupported entities in the web ACL during the migration. Otherwise, if AWS WAF encounters unsupported entities, it stops the process and throws an exception. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.web_acl.migration_stack.create(
                ctx, web_acl_id=value, s3_bucket_name=value, ignore_unsupported_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.web_acl.migration_stack.create web_acl_id=value, s3_bucket_name=value, ignore_unsupported_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_web_acl_migration_stack",
        op_kwargs={
            "WebACLId": web_acl_id,
            "S3BucketName": s3_bucket_name,
            "IgnoreUnsupportedType": ignore_unsupported_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create_multiple(
    hub, ctx, streaming_distribution_config_with_tags: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    This API is deprecated. Amazon CloudFront is deprecating real-time messaging protocol (RTMP) distributions on December 31, 2020. For more information, read the announcement on the Amazon CloudFront discussion forum.

    Args:
        streaming_distribution_config_with_tags(Dict):  The streaming distribution's configuration information. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.streaming_distribution.with_tag.create_multiple(
                ctx, streaming_distribution_config_with_tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.streaming_distribution.with_tag.create_multiple streaming_distribution_config_with_tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_streaming_distribution_with_tags",
        op_kwargs={
            "StreamingDistributionConfigWithTags": streaming_distribution_config_with_tags
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, code_review_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the list of all recommendations for a completed code review.

    Args:
        next_token(str, optional):  Pagination token. . Defaults to None.
        max_results(int, optional):  The maximum number of results that are returned per call. The default is 100. . Defaults to None.
        code_review_arn(str): The Amazon Resource Name (ARN) of the  CodeReview  object. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.recommendation.init.list_all(
                ctx, code_review_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.recommendation.init.list_all code_review_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="list_recommendations",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "CodeReviewArn": code_review_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upload(
    hub,
    ctx,
    document: Dict = None,
    sync_with_public_namespace: bool = None,
    deprecate_existing_entities: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Asynchronously uploads one or more entity definitions to the user's namespace. The document parameter is required if syncWithPublicNamespace and deleteExistingEntites are false. If the syncWithPublicNamespace parameter is set to true, the user's namespace will synchronize with the latest version of the public namespace. If deprecateExistingEntities is set to true, all entities in the latest version will be deleted before the new DefinitionDocument is uploaded. When a user uploads entity definitions for the first time, the service creates a new namespace for the user. The new namespace tracks the public namespace. Currently users can have only one namespace. The namespace version increments whenever a user uploads entity definitions that are backwards-incompatible and whenever a user sets the syncWithPublicNamespace parameter or the deprecateExistingEntities parameter to true. The IDs for all of the entities should be in URN format. Each entity must be in the user's namespace. Users can't create entities in the public namespace, but entity definitions can refer to entities in the public namespace. Valid entities are Device, DeviceModel, Service, Capability, State, Action, Event, Property, Mapping, Enum.

    Args:
        document(Dict, optional): The DefinitionDocument that defines the updated entities. Defaults to None.
        sync_with_public_namespace(bool, optional): A Boolean that specifies whether to synchronize with the latest version of the public namespace. If set to true, the upload will create a new namespace version. Defaults to None.
        deprecate_existing_entities(bool, optional): A Boolean that specifies whether to deprecate all entities in the latest version before uploading the new DefinitionDocument. If set to true, the upload will create a new namespace version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.entity.definition.upload(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.entity.definition.upload
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="upload_entity_definitions",
        op_kwargs={
            "document": document,
            "syncWithPublicNamespace": sync_with_public_namespace,
            "deprecateExistingEntities": deprecate_existing_entities,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    trigger_type: str,
    trigger_value: str,
    target_applications: List,
    disabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a SIP rule which can be used to run a SIP media application as a target for a specific trigger type.

    Args:
        name(str): The name of the SIP rule.
        trigger_type(str): The type of trigger assigned to the SIP rule in TriggerValue, currently RequestUriHostname or ToPhoneNumber.
        trigger_value(str): If TriggerType is RequestUriHostname, the value can be the outbound host name of an Amazon Chime Voice Connector. If TriggerType is ToPhoneNumber, the value can be a customer-owned phone number in the E164 format. The SipMediaApplication specified in the SipRule is triggered if the request URI in an incoming SIP request matches the RequestUriHostname, or if the To header in the incoming SIP request matches the ToPhoneNumber value.
        disabled(bool, optional): Enables or disables a rule. You must disable rules before you can delete them. Defaults to None.
        target_applications(List): List of SIP media applications with priority and AWS Region. Only one SIP application per AWS Region can be used.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.rule.create(
                ctx, name=value, trigger_type=value, trigger_value=value, target_applications=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.rule.create name=value, trigger_type=value, trigger_value=value, target_applications=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_sip_rule",
        op_kwargs={
            "Name": name,
            "TriggerType": trigger_type,
            "TriggerValue": trigger_value,
            "Disabled": disabled,
            "TargetApplications": target_applications,
        },
    )


async def delete(hub, ctx, sip_rule_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a SIP rule. You must disable a SIP rule before you can delete it.

    Args:
        sip_rule_id(str): The SIP rule ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.rule.delete(ctx, sip_rule_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.rule.delete sip_rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_sip_rule",
        op_kwargs={"SipRuleId": sip_rule_id},
    )


async def get(hub, ctx, sip_rule_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and target endpoints.

    Args:
        sip_rule_id(str): The SIP rule ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.rule.get(ctx, sip_rule_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.rule.get sip_rule_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_sip_rule",
        op_kwargs={"SipRuleId": sip_rule_id},
    )


async def list_all(
    hub,
    ctx,
    sip_media_application_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the SIP rules under the administrator's AWS account.

    Args:
        sip_media_application_id(str, optional): The SIP media application ID. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to 100. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.rule.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.rule.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_sip_rules",
        op_kwargs={
            "SipMediaApplicationId": sip_media_application_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    sip_rule_id: str,
    name: str,
    disabled: bool = None,
    target_applications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of the specified SIP rule.

    Args:
        sip_rule_id(str): The SIP rule ID.
        name(str): The new name for the specified SIP rule.
        disabled(bool, optional): The new value specified to indicate whether the rule is disabled. Defaults to None.
        target_applications(List, optional): The new value of the list of target applications. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.rule.update(ctx, sip_rule_id=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.rule.update sip_rule_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_sip_rule",
        op_kwargs={
            "SipRuleId": sip_rule_id,
            "Name": name,
            "Disabled": disabled,
            "TargetApplications": target_applications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, directory_id: str, schema_extension_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels an in-progress schema extension to a Microsoft AD directory. Once a schema extension has started replicating to all domain controllers, the task can no longer be canceled. A schema extension can be canceled during any of the following states; Initializing, CreatingSnapshot, and UpdatingSchema.

    Args:
        directory_id(str): The identifier of the directory whose schema extension will be canceled.
        schema_extension_id(str): The identifier of the schema extension that will be canceled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.schema_extension.cancel(
                ctx, directory_id=value, schema_extension_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.schema_extension.cancel directory_id=value, schema_extension_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="cancel_schema_extension",
        op_kwargs={
            "DirectoryId": directory_id,
            "SchemaExtensionId": schema_extension_id,
        },
    )


async def list_all(
    hub, ctx, directory_id: str, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all schema extensions applied to a Microsoft AD Directory.

    Args:
        directory_id(str): The identifier of the directory from which to retrieve the schema extension information.
        next_token(str, optional): The ListSchemaExtensions.NextToken value from a previous call to ListSchemaExtensions. Pass null if this is the first call. Defaults to None.
        limit(int, optional): The maximum number of items to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.schema_extension.list_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.schema_extension.list_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="list_schema_extensions",
        op_kwargs={
            "DirectoryId": directory_id,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def start(
    hub,
    ctx,
    directory_id: str,
    create_snapshot_before_schema_extension: bool,
    ldif_content: str,
    description: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a schema extension to a Microsoft AD directory.

    Args:
        directory_id(str): The identifier of the directory for which the schema extension will be applied to.
        create_snapshot_before_schema_extension(bool): If true, creates a snapshot of the directory before applying the schema extension.
        ldif_content(str): The LDIF file represented as a string. To construct the LdifContent string, precede each line as it would be formatted in an ldif file with \n. See the example request below for more details. The file size can be no larger than 1MB.
        description(str): A description of the schema extension.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.schema_extension.start(
                ctx,
                directory_id=value,
                create_snapshot_before_schema_extension=value,
                ldif_content=value,
                description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.schema_extension.start directory_id=value, create_snapshot_before_schema_extension=value, ldif_content=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="start_schema_extension",
        op_kwargs={
            "DirectoryId": directory_id,
            "CreateSnapshotBeforeSchemaExtension": create_snapshot_before_schema_extension,
            "LdifContent": ldif_content,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the specified simulation job.

    Args:
        job(str): The simulation job ARN to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.init.cancel(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.init.cancel job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="cancel_simulation_job",
        op_kwargs={"job": job},
    )


async def create(
    hub,
    ctx,
    max_job_duration_in_seconds: int,
    iam_role: str,
    client_request_token: str = None,
    output_location: Dict = None,
    logging_config: Dict = None,
    failure_behavior: str = None,
    robot_applications: List = None,
    simulation_applications: List = None,
    data_sources: List = None,
    tags: Dict = None,
    vpc_config: Dict = None,
    compute: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a simulation job.  After 90 days, simulation jobs expire and will be deleted. They will no longer be accessible.

    Args:
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        output_location(Dict, optional): Location for output files generated by the simulation job. Defaults to None.
        logging_config(Dict, optional): The logging configuration. Defaults to None.
        max_job_duration_in_seconds(int): The maximum simulation job duration in seconds (up to 14 days or 1,209,600 seconds. When maxJobDurationInSeconds is reached, the simulation job will status will transition to Completed.
        iam_role(str): The IAM role name that allows the simulation instance to call the AWS APIs that are specified in its associated policies on your behalf. This is how credentials are passed in to your simulation job. .
        failure_behavior(str, optional): The failure behavior the simulation job.  Continue  Restart the simulation job in the same host instance.  Fail  Stop the simulation job and terminate the instance.  . Defaults to None.
        robot_applications(List, optional): The robot application to use in the simulation job. Defaults to None.
        simulation_applications(List, optional): The simulation application to use in the simulation job. Defaults to None.
        data_sources(List, optional): Specify data sources to mount read-only files from S3 into your simulation. These files are available under /opt/robomaker/datasources/data_source_name.   There is a limit of 100 files and a combined size of 25GB for all DataSourceConfig objects.  . Defaults to None.
        tags(Dict, optional): A map that contains tag keys and tag values that are attached to the simulation job. Defaults to None.
        vpc_config(Dict, optional): If your simulation job accesses resources in a VPC, you provide this parameter identifying the list of security group IDs and subnet IDs. These must belong to the same VPC. You must provide at least one security group and one subnet ID. . Defaults to None.
        compute(Dict, optional): Compute information for the simulation job. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.init.create(
                ctx, max_job_duration_in_seconds=value, iam_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.init.create max_job_duration_in_seconds=value, iam_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="create_simulation_job",
        op_kwargs={
            "clientRequestToken": client_request_token,
            "outputLocation": output_location,
            "loggingConfig": logging_config,
            "maxJobDurationInSeconds": max_job_duration_in_seconds,
            "iamRole": iam_role,
            "failureBehavior": failure_behavior,
            "robotApplications": robot_applications,
            "simulationApplications": simulation_applications,
            "dataSources": data_sources,
            "tags": tags,
            "vpcConfig": vpc_config,
            "compute": compute,
        },
    )


async def describe(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a simulation job.

    Args:
        job(str): The Amazon Resource Name (ARN) of the simulation job to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.init.describe(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.init.describe job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="describe_simulation_job",
        op_kwargs={"job": job},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of simulation jobs. You can optionally provide filters to retrieve specific simulation jobs.

    Args:
        next_token(str, optional): If the previous paginated request did not return all of the remaining results, the response object's nextToken parameter value is set to a token. To retrieve the next set of results, call ListSimulationJobs again and assign that token to the request object's nextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. . Defaults to None.
        max_results(int, optional): When this parameter is used, ListSimulationJobs only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListSimulationJobs request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then ListSimulationJobs returns up to 1000 results and a nextToken value if applicable. . Defaults to None.
        filters(List, optional): Optional filters to limit results. The filter names status and simulationApplicationName and robotApplicationName are supported. When filtering, you must use the complete value of the filtered item. You can use up to three filters, but they must be for the same named item. For example, if you are looking for items with the status Preparing or the status Running. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="list_simulation_jobs",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "filters": filters,
        },
    )


async def restart(hub, ctx, job: str) -> Dict:
    r"""
    **Autogenerated function**

    Restarts a running simulation job.

    Args:
        job(str): The Amazon Resource Name (ARN) of the simulation job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.robomaker.simulation.job.init.restart(ctx, job=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.robomaker.simulation.job.init.restart job=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="robomaker",
        operation="restart_simulation_job",
        op_kwargs={"job": job},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, association_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Runs an association immediately and only one time. This operation can be helpful when troubleshooting associations.

    Args:
        association_ids(List): The association IDs that you want to run immediately and only one time.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.once.start(ctx, association_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.once.start association_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="start_associations_once",
        op_kwargs={"AssociationIds": association_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(hub, ctx, text: str, language_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Detects the key noun phrases found in the text.

    Args:
        text(str): A UTF-8 text string. Each string must contain fewer that 5,000 bytes of UTF-8 encoded characters.
        language_code(str): The language of the input documents. You can specify any of the primary languages supported by Amazon Comprehend. All documents must be in the same language.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.key_phrase.init.detect(
                ctx, text=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.key_phrase.init.detect text=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="detect_key_phrases",
        op_kwargs={"Text": text, "LanguageCode": language_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def update(
    hub, ctx, open_id_connect_provider_arn: str, thumbprint_list: List
) -> None:
    r"""
    **Autogenerated function**

    Replaces the existing list of server certificate thumbprints associated with an OpenID Connect (OIDC) provider resource object with a new list of thumbprints. The list that you pass with this operation completely replaces the existing list of thumbprints. (The lists are not merged.) Typically, you need to update a thumbprint only when the identity provider certificate changes, which occurs rarely. However, if the provider's certificate does change, any attempt to assume an IAM role that specifies the OIDC provider as a principal fails until the certificate thumbprint is updated.  Amazon Web Services secures communication with some OIDC identity providers (IdPs) through our library of trusted certificate authorities (CAs) instead of using a certificate thumbprint to verify your IdP server certificate. These OIDC IdPs include Google, and those that use an Amazon S3 bucket to host a JSON Web Key Set (JWKS) endpoint. In these cases, your legacy thumbprint remains in your configuration, but is no longer used for validation.   Trust for the OIDC provider is derived from the provider certificate and is validated by the thumbprint. Therefore, it is best to limit access to the UpdateOpenIDConnectProviderThumbprint operation to highly privileged users.

    Args:
        open_id_connect_provider_arn(str): The Amazon Resource Name (ARN) of the IAM OIDC provider resource object for which you want to update the thumbprint. You can get a list of OIDC provider ARNs by using the ListOpenIDConnectProviders operation. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        thumbprint_list(List): A list of certificate thumbprints that are associated with the specified IAM OpenID Connect provider. For more information, see CreateOpenIDConnectProvider. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.open_id_connect_provider.thumbprint.update(
                ctx, open_id_connect_provider_arn=value, thumbprint_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.open_id_connect_provider.thumbprint.update open_id_connect_provider_arn=value, thumbprint_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_open_id_connect_provider_thumbprint",
        op_kwargs={
            "OpenIDConnectProviderArn": open_id_connect_provider_arn,
            "ThumbprintList": thumbprint_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(hub, ctx, sending_enabled: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Enable or disable the ability of your account to send email.

    Args:
        sending_enabled(bool, optional): Enables or disables your account's ability to send email. Set to true to enable email sending, or set to false to disable email sending.  If AWS paused your account's ability to send email, you can't use this operation to resume your account's ability to send email. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.account.sending_attribute.put_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.account.sending_attribute.put_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="put_account_sending_attributes",
        op_kwargs={"SendingEnabled": sending_enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub, ctx, relational_database_name: str, page_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all of the runtime parameters offered by the underlying database software, or engine, for a specific database in Amazon Lightsail. In addition to the parameter names and values, this operation returns other information about each parameter. This information includes whether changes require a reboot, whether the parameter is modifiable, the allowed values, and the data types.

    Args:
        relational_database_name(str): The name of your database for which to get parameters.
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetRelationalDatabaseParameters request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.parameter.get_all(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.parameter.get_all relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_parameters",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "pageToken": page_token,
        },
    )


async def update_multiple(
    hub, ctx, relational_database_name: str, parameters: List
) -> Dict:
    r"""
    **Autogenerated function**

    Allows the update of one or more parameters of a database in Amazon Lightsail. Parameter updates don't cause outages; therefore, their application is not subject to the preferred maintenance window. However, there are two ways in which parameter updates are applied: dynamic or pending-reboot. Parameters marked with a dynamic apply type are applied immediately. Parameters marked with a pending-reboot apply type are applied only after the database is rebooted using the reboot relational database operation. The update relational database parameters operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of your database for which to update parameters.
        parameters(List): The database parameters to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.parameter.update_multiple(
                ctx, relational_database_name=value, parameters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.parameter.update_multiple relational_database_name=value, parameters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_relational_database_parameters",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "parameters": parameters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, organization_event_detail_filters: List, locale: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns detailed information about one or more specified events for one or more AWS accounts in your organization. This information includes standard event data (such as the AWS Region and service), an event description, and (depending on the event) possible metadata. This operation doesn't return affected entities, such as the resources related to the event. To return affected entities, use the DescribeAffectedEntitiesForOrganization operation.  Before you can call this operation, you must first enable AWS Health to work with AWS Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.  When you call the DescribeEventDetailsForOrganization operation, specify the organizationEventDetailFilters object in the request. Depending on the AWS Health event type, note the following differences:   To return event details for a public event, you must specify a null value for the awsAccountId parameter. If you specify an account ID for a public event, AWS Health returns an error message because public events aren't specific to an account.   To return event details for an event that is specific to an account in your organization, you must specify the awsAccountId parameter in the request. If you don't specify an account ID, AWS Health returns an error message because the event is specific to an account in your organization.    For more information, see Event.  This operation doesn't support resource-level permissions. You can't use this operation to allow or deny access to specific AWS Health events. For more information, see Resource- and action-based conditions in the AWS Health User Guide.

    Args:
        organization_event_detail_filters(List): A set of JSON elements that includes the awsAccountId and the eventArn.
        locale(str, optional): The locale (language) to return information in. English (en) is the default and the only supported value at this time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.health.event.detail.for_organization.describe(
                ctx, organization_event_detail_filters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.health.event.detail.for_organization.describe organization_event_detail_filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="health",
        operation="describe_event_details_for_organization",
        op_kwargs={
            "organizationEventDetailFilters": organization_event_detail_filters,
            "locale": locale,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, relational_database_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of available log streams for a specific database in Amazon Lightsail.

    Args:
        relational_database_name(str): The name of your database for which to get log streams.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.log.stream.get_all(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.log.stream.get_all relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_log_streams",
        op_kwargs={"relationalDatabaseName": relational_database_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays a list of all entitlements that have been granted to this account. This request returns 20 results per page.

    Args:
        max_results(int, optional): The maximum number of results to return per API request. For example, you submit a ListEntitlements request with MaxResults set at 5. Although 20 items match your request, the service returns no more than the first 5 items. (The service also returns a NextToken value that you can use to fetch the next batch of results.) The service might return fewer results than the MaxResults value. If MaxResults is not included in the request, the service defaults to pagination with a maximum of 20 results per page. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results that you want to see. For example, you submit a ListEntitlements request with MaxResults set at 5. The service returns the first batch of results (up to 5) and a NextToken value. To see the next batch of results, you can submit the ListEntitlements request a second time and specify the NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.entitlement.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.entitlement.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="list_entitlements",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, channel_arn: str, member_arn: str, type_: str, chime_bearer: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a user to a channel. The InvitedBy response field is derived from the request header. A channel member can:   List messages   Send messages   Receive messages   Edit their own messages   Leave the channel   Privacy settings impact this action as follows:   Public Channels: You do not need to be a member to list messages, but you must be a member to send messages.   Private Channels: You must be a member to list or send messages.    The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel to which you're adding users.
        member_arn(str): The ARN of the member you want to add to the channel.
        type_(str): The membership type of a user, DEFAULT or HIDDEN. Default members are always returned as part of ListChannelMemberships. Hidden members are only returned if the type filter in ListChannelMemberships equals HIDDEN. Otherwise hidden members are not returned. This is only supported by moderators.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.membership.init.create(
                ctx, channel_arn=value, member_arn=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.membership.init.create channel_arn=value, member_arn=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_channel_membership",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MemberArn": member_arn,
            "Type": type_,
            "ChimeBearer": chime_bearer,
        },
    )


async def delete(
    hub, ctx, channel_arn: str, member_arn: str, chime_bearer: str = None
) -> None:
    r"""
    **Autogenerated function**

    Removes a member from a channel.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel from which you want to remove the user.
        member_arn(str): The ARN of the member that you're removing from the channel.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.membership.init.delete(
                ctx, channel_arn=value, member_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.membership.init.delete channel_arn=value, member_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_channel_membership",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MemberArn": member_arn,
            "ChimeBearer": chime_bearer,
        },
    )


async def describe(
    hub, ctx, channel_arn: str, member_arn: str, chime_bearer: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the full details of a user's channel membership.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        member_arn(str): The ARN of the member.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.membership.init.describe(
                ctx, channel_arn=value, member_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.membership.init.describe channel_arn=value, member_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="describe_channel_membership",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MemberArn": member_arn,
            "ChimeBearer": chime_bearer,
        },
    )


async def list_all(
    hub,
    ctx,
    channel_arn: str,
    type_: str = None,
    max_results: int = None,
    next_token: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all channel memberships in a channel.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The maximum number of channel memberships that you want returned.
        type_(str, optional): The membership type of a user, DEFAULT or HIDDEN. Default members are always returned as part of ListChannelMemberships. Hidden members are only returned if the type filter in ListChannelMemberships equals HIDDEN. Otherwise hidden members are not returned. Defaults to None.
        max_results(int, optional): The maximum number of channel memberships that you want returned. Defaults to None.
        next_token(str, optional): The token passed by previous API calls until all requested channel memberships are returned. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.membership.init.list_all(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.membership.init.list_all channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_channel_memberships",
        op_kwargs={
            "ChannelArn": channel_arn,
            "Type": type_,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ChimeBearer": chime_bearer,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    user_pool_id: str,
    username: str,
    event_id: str,
    feedback_token: str,
    feedback_value: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides the feedback for an authentication event whether it was from a valid user or not. This feedback is used for improving the risk evaluation decision for the user pool as part of Amazon Cognito advanced security.

    Args:
        user_pool_id(str): The user pool ID.
        username(str): The user pool username.
        event_id(str): The event ID.
        feedback_token(str): The feedback token.
        feedback_value(str): The authentication event feedback value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.auth.event_feedback.update(
                ctx,
                user_pool_id=value,
                username=value,
                event_id=value,
                feedback_token=value,
                feedback_value=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.auth.event_feedback.update user_pool_id=value, username=value, event_id=value, feedback_token=value, feedback_value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_auth_event_feedback",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "EventId": event_id,
            "FeedbackToken": feedback_token,
            "FeedbackValue": feedback_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    format_: str,
    content_range: Dict,
    schedule_name: str = None,
    s3_bucket_name: str = None,
    s3_key_prefix: str = None,
    recurrence: Dict = None,
    client_request_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a recurring schedule for usage reports to deliver to the specified S3 location with a specified daily or weekly interval.

    Args:
        schedule_name(str, optional): The name identifier of the schedule. Defaults to None.
        s3_bucket_name(str, optional): The S3 bucket name of the output reports. If this isn't specified, the report can be retrieved from a download link by calling ListBusinessReportSchedule. . Defaults to None.
        s3_key_prefix(str, optional): The S3 key where the report is delivered. Defaults to None.
        format_(str): The format of the generated report (individual CSV files or zipped files of individual files).
        content_range(Dict): The content range of the reports.
        recurrence(Dict, optional): The recurrence of the reports. If this isn't specified, the report will only be delivered one time when the API is called. . Defaults to None.
        client_request_token(str, optional): The client request token. Defaults to None.
        tags(List, optional): The tags for the business report schedule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.business_report_schedule.create(
                ctx, format_=value, content_range=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.business_report_schedule.create format_=value, content_range=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_business_report_schedule",
        op_kwargs={
            "ScheduleName": schedule_name,
            "S3BucketName": s3_bucket_name,
            "S3KeyPrefix": s3_key_prefix,
            "Format": format_,
            "ContentRange": content_range,
            "Recurrence": recurrence,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, schedule_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the recurring report delivery schedule with the specified schedule ARN.

    Args:
        schedule_arn(str): The ARN of the business report schedule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.business_report_schedule.delete(
                ctx, schedule_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.business_report_schedule.delete schedule_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_business_report_schedule",
        op_kwargs={"ScheduleArn": schedule_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the details of the schedules that a user configured. A download URL of the report associated with each schedule is returned every time this action is called. A new download URL is returned each time, and is valid for 24 hours.

    Args:
        next_token(str, optional): The token used to list the remaining schedules from the previous API call. Defaults to None.
        max_results(int, optional): The maximum number of schedules listed in the call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.business_report_schedule.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.business_report_schedule.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_business_report_schedules",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    schedule_arn: str,
    s3_bucket_name: str = None,
    s3_key_prefix: str = None,
    format_: str = None,
    schedule_name: str = None,
    recurrence: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of the report delivery schedule with the specified schedule ARN.

    Args:
        schedule_arn(str): The ARN of the business report schedule.
        s3_bucket_name(str, optional): The S3 location of the output reports. Defaults to None.
        s3_key_prefix(str, optional): The S3 key where the report is delivered. Defaults to None.
        format_(str, optional): The format of the generated report (individual CSV files or zipped files of individual files). Defaults to None.
        schedule_name(str, optional): The name identifier of the schedule. Defaults to None.
        recurrence(Dict, optional): The recurrence of the reports. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.business_report_schedule.update(
                ctx, schedule_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.business_report_schedule.update schedule_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_business_report_schedule",
        op_kwargs={
            "ScheduleArn": schedule_arn,
            "S3BucketName": s3_bucket_name,
            "S3KeyPrefix": s3_key_prefix,
            "Format": format_,
            "ScheduleName": schedule_name,
            "Recurrence": recurrence,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    auto_ml_job_name: str,
    status_equals: str = None,
    candidate_name_equals: str = None,
    sort_order: str = None,
    sort_by: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the candidates created for the job.

    Args:
        auto_ml_job_name(str): List the candidates created for the job by providing the job's name.
        status_equals(str, optional): List the candidates for the job and filter by status. Defaults to None.
        candidate_name_equals(str, optional): List the candidates for the job and filter by candidate name. Defaults to None.
        sort_order(str, optional): The sort order for the results. The default is Ascending. Defaults to None.
        sort_by(str, optional): The parameter by which to sort the results. The default is Descending. Defaults to None.
        max_results(int, optional): List the job's candidates up to a specified limit. Defaults to None.
        next_token(str, optional): If the previous response was truncated, you receive this token. Use it in your next request to receive the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.candidate_for_auto_ml_job.list(
                ctx, auto_ml_job_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.candidate_for_auto_ml_job.list auto_ml_job_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_candidates_for_auto_ml_job",
        op_kwargs={
            "AutoMLJobName": auto_ml_job_name,
            "StatusEquals": status_equals,
            "CandidateNameEquals": candidate_name_equals,
            "SortOrder": sort_order,
            "SortBy": sort_by,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    assessment_reports_destination: Dict,
    scope: Dict,
    roles: List,
    framework_id: str,
    description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates an assessment in Audit Manager.

    Args:
        name(str):  The name of the assessment to be created. .
        description(str, optional):  The optional description of the assessment to be created. . Defaults to None.
        assessment_reports_destination(Dict):  The assessment report storage destination for the specified assessment that is being created. .
        scope(Dict):  The wrapper that contains the accounts and services in scope for the assessment. .
        roles(List):  The list of roles for the specified assessment. .
        framework_id(str):  The identifier for the specified framework. .
        tags(Dict, optional):  The tags associated with the assessment. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.init.create(
                ctx,
                name=value,
                assessment_reports_destination=value,
                scope=value,
                roles=value,
                framework_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.init.create name=value, assessment_reports_destination=value, scope=value, roles=value, framework_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="create_assessment",
        op_kwargs={
            "name": name,
            "description": description,
            "assessmentReportsDestination": assessment_reports_destination,
            "scope": scope,
            "roles": roles,
            "frameworkId": framework_id,
            "tags": tags,
        },
    )


async def delete(hub, ctx, assessment_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes an assessment in Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.init.delete(ctx, assessment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.init.delete assessment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="delete_assessment",
        op_kwargs={"assessmentId": assessment_id},
    )


async def get(hub, ctx, assessment_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns an assessment from Audit Manager.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.init.get(ctx, assessment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.init.get assessment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_assessment",
        op_kwargs={"assessmentId": assessment_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of current and past assessments from Audit Manager.

    Args:
        next_token(str, optional):  The pagination token used to fetch the next set of results. . Defaults to None.
        max_results(int, optional):  Represents the maximum number of results per page, or per API request call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="list_assessments",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    assessment_id: str,
    scope: Dict,
    assessment_name: str = None,
    assessment_description: str = None,
    assessment_reports_destination: Dict = None,
    roles: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Edits an Audit Manager assessment.

    Args:
        assessment_id(str):  The identifier for the specified assessment. .
        assessment_name(str, optional):  The name of the specified assessment to be updated. . Defaults to None.
        assessment_description(str, optional):  The description of the specified assessment. . Defaults to None.
        scope(Dict):  The scope of the specified assessment. .
        assessment_reports_destination(Dict, optional):  The assessment report storage destination for the specified assessment that is being updated. . Defaults to None.
        roles(List, optional):  The list of roles for the specified assessment. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.assessment.init.update(
                ctx, assessment_id=value, scope=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.assessment.init.update assessment_id=value, scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="update_assessment",
        op_kwargs={
            "assessmentId": assessment_id,
            "assessmentName": assessment_name,
            "assessmentDescription": assessment_description,
            "scope": scope,
            "assessmentReportsDestination": assessment_reports_destination,
            "roles": roles,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def import_(hub, ctx, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Imports an existing Amazon Athena Data Catalog to Glue.

    Args:
        catalog_id(str, optional): The ID of the catalog to import. Currently, this should be the Amazon Web Services account ID. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.catalog.to_glue.import(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.catalog.to_glue.import
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="import_catalog_to_glue",
        op_kwargs={"CatalogId": catalog_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, application_id: str, export_job_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates an export job for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        export_job_request(Dict): Specifies the settings for a job that exports endpoint definitions to an Amazon Simple Storage Service (Amazon S3) bucket.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.export_job.create(
                ctx, application_id=value, export_job_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.export_job.create application_id=value, export_job_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="create_export_job",
        op_kwargs={
            "ApplicationId": application_id,
            "ExportJobRequest": export_job_request,
        },
    )


async def get(hub, ctx, application_id: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the status and settings of a specific export job for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        job_id(str): The unique identifier for the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.export_job.get(ctx, application_id=value, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.export_job.get application_id=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_export_job",
        op_kwargs={"ApplicationId": application_id, "JobId": job_id},
    )


async def get_all(
    hub, ctx, application_id: str, page_size: str = None, token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the status and settings of all the export jobs for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        token(str, optional): The NextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.export_job.get_all(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.export_job.get_all application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_export_jobs",
        op_kwargs={
            "ApplicationId": application_id,
            "PageSize": page_size,
            "Token": token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, directory_id: str, alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an alias for a directory and assigns the alias to the directory. The alias is used to construct the access URL for the directory, such as http://<alias>.awsapps.com.  After an alias has been created, it cannot be deleted or reused, so this operation should only be used when absolutely necessary.

    Args:
        directory_id(str): The identifier of the directory for which to create the alias.
        alias(str): The requested alias. The alias must be unique amongst all aliases in AWS. This operation throws an EntityAlreadyExistsException error if the alias already exists.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.alias.create(ctx, directory_id=value, alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.alias.create directory_id=value, alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_alias",
        op_kwargs={"DirectoryId": directory_id, "Alias": alias},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, subnet_group_name: str, subnet_ids: List, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new subnet group.

    Args:
        subnet_group_name(str): A name for the subnet group. This value is stored as a lowercase string. .
        description(str, optional): A description for the subnet group. Defaults to None.
        subnet_ids(List): A list of VPC subnet IDs for the subnet group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.subnet_group.create(
                ctx, subnet_group_name=value, subnet_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.subnet_group.create subnet_group_name=value, subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="create_subnet_group",
        op_kwargs={
            "SubnetGroupName": subnet_group_name,
            "Description": description,
            "SubnetIds": subnet_ids,
        },
    )


async def delete(hub, ctx, subnet_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a subnet group.  You cannot delete a subnet group if it is associated with any DAX clusters.

    Args:
        subnet_group_name(str): The name of the subnet group to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.subnet_group.delete(ctx, subnet_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.subnet_group.delete subnet_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="delete_subnet_group",
        op_kwargs={"SubnetGroupName": subnet_group_name},
    )


async def describe_all(
    hub,
    ctx,
    subnet_group_names: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of subnet group descriptions. If a subnet group name is specified, the list will contain only the description of that group.

    Args:
        subnet_group_names(List, optional): The name of the subnet group. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. The value for MaxResults must be between 20 and 100. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.subnet_group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.subnet_group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="describe_subnet_groups",
        op_kwargs={
            "SubnetGroupNames": subnet_group_names,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, subnet_group_name: str, description: str = None, subnet_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing subnet group.

    Args:
        subnet_group_name(str): The name of the subnet group.
        description(str, optional): A description of the subnet group. Defaults to None.
        subnet_ids(List, optional): A list of subnet IDs in the subnet group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.subnet_group.update(ctx, subnet_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.subnet_group.update subnet_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="update_subnet_group",
        op_kwargs={
            "SubnetGroupName": subnet_group_name,
            "Description": description,
            "SubnetIds": subnet_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    identity_management_type: str,
    inbound_calls_enabled: bool,
    outbound_calls_enabled: bool,
    client_token: str = None,
    instance_alias: str = None,
    directory_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Initiates an Amazon Connect instance with all the supported channels enabled. It does not attach any storage, such as Amazon Simple Storage Service (Amazon S3) or Amazon Kinesis. It also does not allow for any configurations on features, such as Contact Lens for Amazon Connect.  Amazon Connect enforces a limit on the total number of instances that you can create or delete in 30 days. If you exceed this limit, you will get an error message indicating there has been an excessive number of attempts at creating or deleting instances. You must wait 30 days before you can restart creating and deleting instances in your account.

    Args:
        client_token(str, optional): The idempotency token. Defaults to None.
        identity_management_type(str): The type of identity management for your Amazon Connect users.
        instance_alias(str, optional): The name for your instance. Defaults to None.
        directory_id(str, optional): The identifier for the directory. Defaults to None.
        inbound_calls_enabled(bool): Your contact center handles incoming contacts.
        outbound_calls_enabled(bool): Your contact center allows outbound calls.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.init.create(
                ctx,
                identity_management_type=value,
                inbound_calls_enabled=value,
                outbound_calls_enabled=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.init.create identity_management_type=value, inbound_calls_enabled=value, outbound_calls_enabled=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="create_instance",
        op_kwargs={
            "ClientToken": client_token,
            "IdentityManagementType": identity_management_type,
            "InstanceAlias": instance_alias,
            "DirectoryId": directory_id,
            "InboundCallsEnabled": inbound_calls_enabled,
            "OutboundCallsEnabled": outbound_calls_enabled,
        },
    )


async def delete(hub, ctx, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Deletes the Amazon Connect instance. Amazon Connect enforces a limit on the total number of instances that you can create or delete in 30 days. If you exceed this limit, you will get an error message indicating there has been an excessive number of attempts at creating or deleting instances. You must wait 30 days before you can restart creating and deleting instances in your account.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.init.delete(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.init.delete instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="delete_instance",
        op_kwargs={"InstanceId": instance_id},
    )


async def describe(hub, ctx, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Returns the current state of the specified instance identifier. It tracks the instance while it is being created and returns an error status, if applicable.  If an instance is not created successfully, the instance status reason field returns details relevant to the reason. The instance in a failed state is returned only for 24 hours after the CreateInstance API was invoked.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.init.describe(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.init.describe instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_instance",
        op_kwargs={"InstanceId": instance_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. Return a list of instances which are in active state, creation-in-progress state, and failed state. Instances that aren't successfully created (they are in a failed state) are returned only for 24 hours after the CreateInstance API was invoked.

    Args:
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.instance.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.instance.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_instances",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_name: str,
    domain_name_configurations: List = None,
    mutual_tls_authentication: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a domain name.

    Args:
        domain_name(str): The domain name.
        domain_name_configurations(List, optional): The domain name configurations. Defaults to None.
        mutual_tls_authentication(Dict, optional): The mutual TLS authentication configuration for a custom domain name. Defaults to None.
        tags(Dict, optional): The collection of tags associated with a domain name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.domain_name.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.domain_name.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_domain_name",
        op_kwargs={
            "DomainName": domain_name,
            "DomainNameConfigurations": domain_name_configurations,
            "MutualTlsAuthentication": mutual_tls_authentication,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, domain_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a domain name.

    Args:
        domain_name(str): The domain name.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.domain_name.delete(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.domain_name.delete domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_domain_name",
        op_kwargs={"DomainName": domain_name},
    )


async def get(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a domain name.

    Args:
        domain_name(str): The domain name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.domain_name.get(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.domain_name.get domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_domain_name",
        op_kwargs={"DomainName": domain_name},
    )


async def get_all(hub, ctx, max_results: str = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the domain names for an AWS account.

    Args:
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.domain_name.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.domain_name.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_domain_names",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    domain_name: str,
    domain_name_configurations: List = None,
    mutual_tls_authentication: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a domain name.

    Args:
        domain_name(str): The domain name.
        domain_name_configurations(List, optional): The domain name configurations. Defaults to None.
        mutual_tls_authentication(Dict, optional): The mutual TLS authentication configuration for a custom domain name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.domain_name.update(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.domain_name.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_domain_name",
        op_kwargs={
            "DomainName": domain_name,
            "DomainNameConfigurations": domain_name_configurations,
            "MutualTlsAuthentication": mutual_tls_authentication,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, filters: List = None, max_records: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a paginated list of individual assessments based on filter settings. These filter settings can specify a combination of premigration assessment runs, migration tasks, and assessment status values.

    Args:
        filters(List, optional): Filters applied to the individual assessments described in the form of key-value pairs. Valid filter names: replication-task-assessment-run-arn, replication-task-arn, status . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.individual_assessment.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.individual_assessment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_replication_task_individual_assessments",
        op_kwargs={"Filters": filters, "MaxRecords": max_records, "Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    group_name: str = None,
    group: str = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of ARNs of the resources that are members of a specified resource group.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:ListGroupResources     cloudformation:DescribeStacks     cloudformation:ListStackResources     tag:GetResources

    Args:
        group_name(str, optional):    Deprecated - don't use this parameter. Use the Group request field instead.   . Defaults to None.
        group(str, optional): The name or the ARN of the resource group. Defaults to None.
        filters(List, optional): Filters, formatted as ResourceFilter objects, that you want to apply to a ListGroupResources operation. Filters the results to include only those of the specified resource types.    resource-type - Filter resources by their type. Specify up to five resource types in the format AWS::ServiceCode::ResourceType. For example, AWS::EC2::Instance, or AWS::S3::Bucket.    When you specify a resource-type filter for ListGroupResources, AWS Resource Groups validates your filter resource types against the types that are defined in the query associated with the group. For example, if a group contains only S3 buckets because its query specifies only that resource type, but your resource-type filter includes EC2 instances, AWS Resource Groups does not filter for EC2 instances. In this case, a ListGroupResources request returns a BadRequestException error with a message similar to the following:  The resource types specified as filters in the request are not valid.  The error includes a list of resource types that failed the validation because they are not part of the query associated with the group. This validation doesn't occur when the group query specifies AWS::AllSupported, because a group based on such a query can contain any of the allowed resource types for the query type (tag-based or AWS CloudFormation stack-based queries). Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.resource.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.resource.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="list_group_resources",
        op_kwargs={
            "GroupName": group_name,
            "Group": group,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def upgrade(
    hub,
    ctx,
    development_schema_arn: str,
    published_schema_arn: str,
    minor_version: str,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Upgrades a published schema under a new minor version revision using the current contents of DevelopmentSchemaArn.

    Args:
        development_schema_arn(str): The ARN of the development schema with the changes used for the upgrade.
        published_schema_arn(str): The ARN of the published schema to be upgraded.
        minor_version(str): Identifies the minor version of the published schema that will be created. This parameter is NOT optional.
        dry_run(bool, optional): Used for testing whether the Development schema provided is backwards compatible, or not, with the publish schema provided by the user to be upgraded. If schema compatibility fails, an exception would be thrown else the call would succeed. This parameter is optional and defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.published_schema.init.upgrade(
                ctx, development_schema_arn=value, published_schema_arn=value, minor_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.published_schema.init.upgrade development_schema_arn=value, published_schema_arn=value, minor_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="upgrade_published_schema",
        op_kwargs={
            "DevelopmentSchemaArn": development_schema_arn,
            "PublishedSchemaArn": published_schema_arn,
            "MinorVersion": minor_version,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, directory_id: str, remote_domain_name: str, dns_ip_addrs: List
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a conditional forwarder associated with your AWS directory. Conditional forwarders are required in order to set up a trust relationship with another domain. The conditional forwarder points to the trusted domain.

    Args:
        directory_id(str): The directory ID of the AWS directory for which you are creating the conditional forwarder.
        remote_domain_name(str): The fully qualified domain name (FQDN) of the remote domain with which you will set up a trust relationship.
        dns_ip_addrs(List): The IP addresses of the remote DNS server associated with RemoteDomainName.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.conditional_forwarder.create(
                ctx, directory_id=value, remote_domain_name=value, dns_ip_addrs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.conditional_forwarder.create directory_id=value, remote_domain_name=value, dns_ip_addrs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_conditional_forwarder",
        op_kwargs={
            "DirectoryId": directory_id,
            "RemoteDomainName": remote_domain_name,
            "DnsIpAddrs": dns_ip_addrs,
        },
    )


async def delete(hub, ctx, directory_id: str, remote_domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a conditional forwarder that has been set up for your AWS directory.

    Args:
        directory_id(str): The directory ID for which you are deleting the conditional forwarder.
        remote_domain_name(str): The fully qualified domain name (FQDN) of the remote domain with which you are deleting the conditional forwarder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.conditional_forwarder.delete(
                ctx, directory_id=value, remote_domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.conditional_forwarder.delete directory_id=value, remote_domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="delete_conditional_forwarder",
        op_kwargs={"DirectoryId": directory_id, "RemoteDomainName": remote_domain_name},
    )


async def describe_all(
    hub, ctx, directory_id: str, remote_domain_names: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Obtains information about the conditional forwarders for this account. If no input parameters are provided for RemoteDomainNames, this request describes all conditional forwarders for the specified directory ID.

    Args:
        directory_id(str): The directory ID for which to get the list of associated conditional forwarders.
        remote_domain_names(List, optional): The fully qualified domain names (FQDN) of the remote domains for which to get the list of associated conditional forwarders. If this member is null, all conditional forwarders are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.conditional_forwarder.describe_all(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.conditional_forwarder.describe_all directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_conditional_forwarders",
        op_kwargs={
            "DirectoryId": directory_id,
            "RemoteDomainNames": remote_domain_names,
        },
    )


async def update(
    hub, ctx, directory_id: str, remote_domain_name: str, dns_ip_addrs: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a conditional forwarder that has been set up for your AWS directory.

    Args:
        directory_id(str): The directory ID of the AWS directory for which to update the conditional forwarder.
        remote_domain_name(str): The fully qualified domain name (FQDN) of the remote domain with which you will set up a trust relationship.
        dns_ip_addrs(List): The updated IP addresses of the remote DNS server associated with the conditional forwarder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.conditional_forwarder.update(
                ctx, directory_id=value, remote_domain_name=value, dns_ip_addrs=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.conditional_forwarder.update directory_id=value, remote_domain_name=value, dns_ip_addrs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="update_conditional_forwarder",
        op_kwargs={
            "DirectoryId": directory_id,
            "RemoteDomainName": remote_domain_name,
            "DnsIpAddrs": dns_ip_addrs,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "sql_injection_match_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates a SqlInjectionMatchSet, which you use to allow, block, or count requests that contain snippets of SQL code in a specified part of web requests. AWS WAF searches for character sequences that are likely to be malicious strings. To create and configure a SqlInjectionMatchSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateSqlInjectionMatchSet request.   Submit a CreateSqlInjectionMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateSqlInjectionMatchSet request.   Submit an UpdateSqlInjectionMatchSet request to specify the parts of web requests in which you want to allow, block, or count malicious SQL code.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description for the SqlInjectionMatchSet that you're creating. You can't change Name after you create the SqlInjectionMatchSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.sql_injection_match_set_.create(
                ctx, name=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.sql_injection_match_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="create_sql_injection_match_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, sql_injection_match_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes a SqlInjectionMatchSet. You can't delete a SqlInjectionMatchSet if it's still used in any Rules or if it still contains any SqlInjectionMatchTuple objects. If you just want to remove a SqlInjectionMatchSet from a Rule, use UpdateRule. To permanently delete a SqlInjectionMatchSet from AWS WAF, perform the following steps:   Update the SqlInjectionMatchSet to remove filters, if any. For more information, see UpdateSqlInjectionMatchSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteSqlInjectionMatchSet request.   Submit a DeleteSqlInjectionMatchSet request.

    Args:
        sql_injection_match_set_id(str): The SqlInjectionMatchSetId of the SqlInjectionMatchSet that you want to delete. SqlInjectionMatchSetId is returned by CreateSqlInjectionMatchSet and by ListSqlInjectionMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.sql_injection_match_set_.delete(
                ctx, sql_injection_match_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.sql_injection_match_set.delete sql_injection_match_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="delete_sql_injection_match_set",
        op_kwargs={
            "SqlInjectionMatchSetId": sql_injection_match_set_id,
            "ChangeToken": change_token,
        },
    )


async def get(hub, ctx, sql_injection_match_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the SqlInjectionMatchSet that is specified by SqlInjectionMatchSetId.

    Args:
        sql_injection_match_set_id(str): The SqlInjectionMatchSetId of the SqlInjectionMatchSet that you want to get. SqlInjectionMatchSetId is returned by CreateSqlInjectionMatchSet and by ListSqlInjectionMatchSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.sql_injection_match_set_.get(
                ctx, sql_injection_match_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.sql_injection_match_set.get sql_injection_match_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="get_sql_injection_match_set",
        op_kwargs={"SqlInjectionMatchSetId": sql_injection_match_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of SqlInjectionMatchSet objects.

    Args:
        next_marker(str, optional): If you specify a value for Limit and you have more SqlInjectionMatchSet objects than the value of Limit, AWS WAF returns a NextMarker value in the response that allows you to list another group of SqlInjectionMatchSets. For the second and subsequent ListSqlInjectionMatchSets requests, specify the value of NextMarker from the previous response to get information about another batch of SqlInjectionMatchSets. Defaults to None.
        limit(int, optional): Specifies the number of SqlInjectionMatchSet objects that you want AWS WAF to return for this request. If you have more SqlInjectionMatchSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of Rules. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.sql_injection_match_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.sql_injection_match_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="list_sql_injection_match_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(
    hub, ctx, sql_injection_match_set_id: str, change_token: str, updates: List
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes SqlInjectionMatchTuple objects (filters) in a SqlInjectionMatchSet. For each SqlInjectionMatchTuple object, you specify the following values:    Action: Whether to insert the object into or delete the object from the array. To change a SqlInjectionMatchTuple, you delete the existing object and add a new one.    FieldToMatch: The part of web requests that you want AWS WAF to inspect and, if you want AWS WAF to inspect a header or custom query parameter, the name of the header or parameter.    TextTransformation: Which text transformation, if any, to perform on the web request before inspecting the request for snippets of malicious SQL code. You can only specify a single type of TextTransformation.   You use SqlInjectionMatchSet objects to specify which CloudFront requests that you want to allow, block, or count. For example, if you're receiving requests that contain snippets of SQL code in the query string and you want to block the requests, you can create a SqlInjectionMatchSet with the applicable settings, and then configure AWS WAF to block the requests.  To create and configure a SqlInjectionMatchSet, perform the following steps:   Submit a CreateSqlInjectionMatchSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateIPSet request.   Submit an UpdateSqlInjectionMatchSet request to specify the parts of web requests that you want AWS WAF to inspect for snippets of SQL code.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        sql_injection_match_set_id(str): The SqlInjectionMatchSetId of the SqlInjectionMatchSet that you want to update. SqlInjectionMatchSetId is returned by CreateSqlInjectionMatchSet and by ListSqlInjectionMatchSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of SqlInjectionMatchSetUpdate objects that you want to insert into or delete from a SqlInjectionMatchSet. For more information, see the applicable data types:    SqlInjectionMatchSetUpdate: Contains Action and SqlInjectionMatchTuple     SqlInjectionMatchTuple: Contains FieldToMatch and TextTransformation     FieldToMatch: Contains Data and Type   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.sql_injection_match_set_.update(
                ctx, sql_injection_match_set_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.sql_injection_match_set.update sql_injection_match_set_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="update_sql_injection_match_set",
        op_kwargs={
            "SqlInjectionMatchSetId": sql_injection_match_set_id,
            "ChangeToken": change_token,
            "Updates": updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, max_results: int = None, mode: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Send an request with an empty body to the regional API endpoint to get your account API endpoint.

    Args:
        max_results(int, optional): Optional. Max number of endpoints, up to twenty, that will be returned at one time. Defaults to None.
        mode(str, optional): Optional field, defaults to DEFAULT. Specify DEFAULT for this operation to return your endpoints if any exist, or to create an endpoint for you and return it if one doesn't already exist. Specify GET_ONLY to return your endpoints if any exist, or an empty list if none exist. Defaults to None.
        next_token(str, optional): Use this string, provided with the response to a previous request, to request the next batch of endpoints. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.endpoint.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.endpoint.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="describe_endpoints",
        op_kwargs={"MaxResults": max_results, "Mode": mode, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def disable(hub, ctx, service_principal: str) -> None:
    r"""
    **Autogenerated function**

    Disables the integration of an AWS service (the service that is specified by ServicePrincipal) with AWS Organizations. When you disable integration, the specified service no longer can create a service-linked role in new accounts in your organization. This means the service can't perform operations on your behalf on any new accounts in your organization. The service can still perform operations in older accounts until the service completes its clean-up from AWS Organizations.  We  strongly recommend  that you don't use this command to disable integration between AWS Organizations and the specified AWS service. Instead, use the console or commands that are provided by the specified service. This lets the trusted service perform any required initialization when enabling trusted access, such as creating any required resources and any required clean up of resources when disabling trusted access.  For information about how to disable trusted service access to your organization using the trusted service, see the Learn more link under the Supports Trusted Access column at AWS services that you can use with AWS Organizations. on this page. If you disable access by using this command, it causes the following actions to occur:   The service can no longer create a service-linked role in the accounts in your organization. This means that the service can't perform operations on your behalf on any new accounts in your organization. The service can still perform operations in older accounts until the service completes its clean-up from AWS Organizations.    The service can no longer perform tasks in the member accounts in the organization, unless those operations are explicitly permitted by the IAM policies that are attached to your roles. This includes any data aggregation from the member accounts to the management account, or to a delegated administrator account, where relevant.   Some services detect this and clean up any remaining data or resources related to the integration, while other services stop accessing the organization but leave any historical data and configuration in place to support a possible re-enabling of the integration.   Using the other service's console or commands to disable the integration ensures that the other service is aware that it can clean up any resources that are required only for the integration. How the service cleans up its resources in the organization's accounts depends on that service. For more information, see the documentation for the other AWS service.   After you perform the DisableAWSServiceAccess operation, the specified service can no longer perform operations in your organization's accounts  For more information about integrating other services with AWS Organizations, including the list of services that work with Organizations, see Integrating AWS Organizations with Other AWS Services in the AWS Organizations User Guide.  This operation can be called only from the organization's management account.

    Args:
        service_principal(str): The service principal name of the AWS service for which you want to disable integration with your organization. This is typically in the form of a URL, such as  service-abbreviation.amazonaws.com.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.aws_service_access.init.disable(
                ctx, service_principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.aws_service_access.init.disable service_principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="disable_aws_service_access",
        op_kwargs={"ServicePrincipal": service_principal},
    )


async def enable(hub, ctx, service_principal: str) -> None:
    r"""
    **Autogenerated function**

    Enables the integration of an AWS service (the service that is specified by ServicePrincipal) with AWS Organizations. When you enable integration, you allow the specified service to create a service-linked role in all the accounts in your organization. This allows the service to perform operations on your behalf in your organization and its accounts.  We recommend that you enable integration between AWS Organizations and the specified AWS service by using the console or commands that are provided by the specified service. Doing so ensures that the service is aware that it can create the resources that are required for the integration. How the service creates those resources in the organization's accounts depends on that service. For more information, see the documentation for the other AWS service.  For more information about enabling services to integrate with AWS Organizations, see Integrating AWS Organizations with Other AWS Services in the AWS Organizations User Guide.  This operation can be called only from the organization's management account and only if the organization has enabled all features.

    Args:
        service_principal(str): The service principal name of the AWS service for which you want to enable integration with your organization. This is typically in the form of a URL, such as  service-abbreviation.amazonaws.com.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.aws_service_access.init.enable(
                ctx, service_principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.aws_service_access.init.enable service_principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="enable_aws_service_access",
        op_kwargs={"ServicePrincipal": service_principal},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, entries: List, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Batch operation to revoke permissions from the principal.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        entries(List): A list of up to 20 entries for resource permissions to be revoked by batch operation to the principal.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.revoke_permission.batch(ctx, entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.revoke_permission.batch entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="batch_revoke_permissions",
        op_kwargs={"CatalogId": catalog_id, "Entries": entries},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    job_id: str,
    include_resource_placeholders: bool = None,
    include_service_level_template: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the policy that was generated using StartPolicyGeneration.

    Args:
        include_resource_placeholders(bool, optional): The level of detail that you want to generate. You can specify whether to generate policies with placeholders for resource ARNs for actions that support resource level granularity in policies. For example, in the resource section of a policy, you can receive a placeholder such as "Resource":"arn:aws:s3:::${BucketName}" instead of "*". Defaults to None.
        include_service_level_template(bool, optional): The level of detail that you want to generate. You can specify whether to generate service-level policies.  Access Analyzer uses iam:servicelastaccessed to identify services that have been used recently to create this service-level template. Defaults to None.
        job_id(str): The JobId that is returned by the StartPolicyGeneration operation. The JobId can be used with GetGeneratedPolicy to retrieve the generated policies or used with CancelPolicyGeneration to cancel the policy generation request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.accessanalyzer.generated_policy.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.accessanalyzer.generated_policy.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="accessanalyzer",
        operation="get_generated_policy",
        op_kwargs={
            "includeResourcePlaceholders": include_resource_placeholders,
            "includeServiceLevelTemplate": include_service_level_template,
            "jobId": job_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    project_id: str,
    user_arn: str,
    project_role: str,
    client_request_token: str = None,
    remote_access_allowed: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an IAM user to the team for an AWS CodeStar project.

    Args:
        project_id(str): The ID of the project to which you will add the IAM user.
        client_request_token(str, optional): A user- or system-generated token that identifies the entity that requested the team member association to the project. This token can be used to repeat the request. Defaults to None.
        user_arn(str): The Amazon Resource Name (ARN) for the IAM user you want to add to the AWS CodeStar project.
        project_role(str): The AWS CodeStar project role that will apply to this user. This role determines what actions a user can take in an AWS CodeStar project.
        remote_access_allowed(bool, optional): Whether the team member is allowed to use an SSH public/private key pair to remotely access project resources, for example Amazon EC2 instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.team_member.associate(
                ctx, project_id=value, user_arn=value, project_role=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.team_member.associate project_id=value, user_arn=value, project_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="associate_team_member",
        op_kwargs={
            "projectId": project_id,
            "clientRequestToken": client_request_token,
            "userArn": user_arn,
            "projectRole": project_role,
            "remoteAccessAllowed": remote_access_allowed,
        },
    )


async def disassociate(hub, ctx, project_id: str, user_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a user from a project. Removing a user from a project also removes the IAM policies from that user that allowed access to the project and its resources. Disassociating a team member does not remove that user's profile from AWS CodeStar. It does not remove the user from IAM.

    Args:
        project_id(str): The ID of the AWS CodeStar project from which you want to remove a team member.
        user_arn(str): The Amazon Resource Name (ARN) of the IAM user or group whom you want to remove from the project.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.team_member.disassociate(
                ctx, project_id=value, user_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.team_member.disassociate project_id=value, user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="disassociate_team_member",
        op_kwargs={"projectId": project_id, "userArn": user_arn},
    )


async def list_all(
    hub, ctx, project_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all team members associated with a project.

    Args:
        project_id(str): The ID of the project for which you want to list team members.
        next_token(str, optional): The continuation token for the next set of results, if the results cannot be returned in one response. Defaults to None.
        max_results(int, optional): The maximum number of team members you want returned in a response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.team_member.list_all(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.team_member.list_all project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="list_team_members",
        op_kwargs={
            "projectId": project_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    project_id: str,
    user_arn: str,
    project_role: str = None,
    remote_access_allowed: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a team member's attributes in an AWS CodeStar project. For example, you can change a team member's role in the project, or change whether they have remote access to project resources.

    Args:
        project_id(str): The ID of the project.
        user_arn(str): The Amazon Resource Name (ARN) of the user for whom you want to change team membership attributes.
        project_role(str, optional): The role assigned to the user in the project. Project roles have different levels of access. For more information, see Working with Teams in the AWS CodeStar User Guide. Defaults to None.
        remote_access_allowed(bool, optional): Whether a team member is allowed to remotely access project resources using the SSH public key associated with the user's profile. Even if this is set to True, the user must associate a public key with their profile before the user can access resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.team_member.update(
                ctx, project_id=value, user_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.team_member.update project_id=value, user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="update_team_member",
        op_kwargs={
            "projectId": project_id,
            "userArn": user_arn,
            "projectRole": project_role,
            "remoteAccessAllowed": remote_access_allowed,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, organization_id: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified retention policy from the specified organization.

    Args:
        organization_id(str): The organization ID.
        id_(str): The retention policy ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.retention_policy.delete(
                ctx, organization_id=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.retention_policy.delete organization_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_retention_policy",
        op_kwargs={"OrganizationId": organization_id, "Id": id_},
    )


async def put(
    hub,
    ctx,
    organization_id: str,
    name: str,
    folder_configurations: List,
    id_: str = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Puts a retention policy to the specified organization.

    Args:
        organization_id(str): The organization ID.
        id_(str, optional): The retention policy ID. Defaults to None.
        name(str): The retention policy name.
        description(str, optional): The retention policy description. Defaults to None.
        folder_configurations(List): The retention policy folder configurations.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.retention_policy.put(
                ctx, organization_id=value, name=value, folder_configurations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.retention_policy.put organization_id=value, name=value, folder_configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="put_retention_policy",
        op_kwargs={
            "OrganizationId": organization_id,
            "Id": id_,
            "Name": name,
            "Description": description,
            "FolderConfigurations": folder_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def delete(hub, ctx, installation_media_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the installation medium for a DB engine that requires an on-premises customer provided license, such as Microsoft SQL Server.

    Args:
        installation_media_id(str): The installation medium ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.installation_media.delete(ctx, installation_media_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.installation_media.delete installation_media_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_installation_media",
        op_kwargs={"InstallationMediaId": installation_media_id},
    )


async def describe(
    hub,
    ctx,
    installation_media_id: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the available installation media for a DB engine that requires an on-premises customer provided license, such as Microsoft SQL Server.

    Args:
        installation_media_id(str, optional): The installation medium ID. Defaults to None.
        filters(List, optional): A filter that specifies one or more installation media to describe. Supported filters include the following:    custom-availability-zone-id - Accepts custom Availability Zone (AZ) identifiers. The results list includes information about only the custom AZs identified by these identifiers.    engine - Accepts database engines. The results list includes information about only the database engines identified by these identifiers. For more information about the valid engines for installation media, see ImportInstallationMedia.  . Defaults to None.
        max_records(int, optional): An optional pagination token provided by a previous DescribeInstallationMedia request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.installation_media.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.installation_media.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_installation_media",
        op_kwargs={
            "InstallationMediaId": installation_media_id,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def import_(
    hub,
    ctx,
    custom_availability_zone_id: str,
    engine: str,
    engine_version: str,
    engine_installation_media_path: str,
    os_installation_media_path: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports the installation media for a DB engine that requires an on-premises customer provided license, such as SQL Server.

    Args:
        custom_availability_zone_id(str): The identifier of the custom Availability Zone (AZ) to import the installation media to.
        engine(str): The name of the database engine to be used for this instance.  The list only includes supported DB engines that require an on-premises customer provided license.  Valid Values:     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   .
        engine_version(str): The version number of the database engine to use. For a list of valid engine versions, call DescribeDBEngineVersions. The following are the database engines and links to information about the major and minor versions. The list only includes DB engines that require an on-premises customer provided license.  Microsoft SQL Server  See  Microsoft SQL Server Versions on Amazon RDS in the Amazon RDS User Guide. .
        engine_installation_media_path(str): The path to the installation medium for the specified DB engine. Example: SQLServerISO/en_sql_server_2016_enterprise_x64_dvd_8701793.iso .
        os_installation_media_path(str): The path to the installation medium for the operating system associated with the specified DB engine. Example: WindowsISO/en_windows_server_2016_x64_dvd_9327751.iso .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.installation_media.import(ctx, custom_availability_zone_id=value, engine=value, engine_version=value, engine_installation_media_path=value, os_installation_media_path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.installation_media.import custom_availability_zone_id=value, engine=value, engine_version=value, engine_installation_media_path=value, os_installation_media_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="import_installation_media",
        op_kwargs={
            "CustomAvailabilityZoneId": custom_availability_zone_id,
            "Engine": engine,
            "EngineVersion": engine_version,
            "EngineInstallationMediaPath": engine_installation_media_path,
            "OSInstallationMediaPath": os_installation_media_path,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    directory_arn: str,
    object_reference: Dict,
    schema_facet: Dict,
    attribute_names: List,
    consistency_level: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves attributes within a facet that are associated with an object.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where the object resides.
        object_reference(Dict): Reference that identifies the object whose attributes will be retrieved.
        consistency_level(str, optional): The consistency level at which to retrieve the attributes on an object. Defaults to None.
        schema_facet(Dict): Identifier for the facet whose attributes will be retrieved. See SchemaFacet for details.
        attribute_names(List): List of attribute names whose values will be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.attribute.get_all(
                ctx,
                directory_arn=value,
                object_reference=value,
                schema_facet=value,
                attribute_names=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.attribute.get_all directory_arn=value, object_reference=value, schema_facet=value, attribute_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="get_object_attributes",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ObjectReference": object_reference,
            "ConsistencyLevel": consistency_level,
            "SchemaFacet": schema_facet,
            "AttributeNames": attribute_names,
        },
    )


async def list_all(
    hub,
    ctx,
    directory_arn: str,
    object_reference: Dict,
    next_token: str = None,
    max_results: int = None,
    consistency_level: str = None,
    facet_filter: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all attributes that are associated with an object.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where the object resides. For more information, see arns.
        object_reference(Dict): The reference that identifies the object whose attributes will be listed.
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum number of items to be retrieved in a single call. This is an approximate number. Defaults to None.
        consistency_level(str, optional): Represents the manner and timing in which the successful write or update of an object is reflected in a subsequent read operation of that same object. Defaults to None.
        facet_filter(Dict, optional): Used to filter the list of object attributes that are associated with a certain facet. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.attribute.list_all(
                ctx, directory_arn=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.attribute.list_all directory_arn=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_object_attributes",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ObjectReference": object_reference,
            "NextToken": next_token,
            "MaxResults": max_results,
            "ConsistencyLevel": consistency_level,
            "FacetFilter": facet_filter,
        },
    )


async def update_multiple(
    hub, ctx, directory_arn: str, object_reference: Dict, attribute_updates: List
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a given object's attributes.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where the object resides. For more information, see arns.
        object_reference(Dict): The reference that identifies the object.
        attribute_updates(List): The attributes update structure.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.object_.attribute.update_multiple(
                ctx, directory_arn=value, object_reference=value, attribute_updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.object_.attribute.update_multiple directory_arn=value, object_reference=value, attribute_updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="update_object_attributes",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ObjectReference": object_reference,
            "AttributeUpdates": attribute_updates,
        },
    )
